pub fn build_audit_header_map(
input: AuditJsonHeaderInput,
) -> Result<Map<String, Value>, Error>Expand description
Build the audit header as an object map for composed output contracts such as review briefs.
Errors
Returns a serde error if one of the typed header fields cannot be converted to JSON, or if the typed header unexpectedly does not serialize to an object.