serialize_audit_json

Function serialize_audit_json 

pub fn serialize_audit_json<DeadCode, Duplication, Complexity>(
    input: AuditJsonOutputInput<DeadCode, Duplication, Complexity>,
    mode: RootEnvelopeMode,
    analysis_run_id: Option<&str>,
) -> Result<Value, Error>
where DeadCode: Serialize, Duplication: Serialize, Complexity: Serialize,
Serialize a typed audit JSON output envelope.

Errors

Returns a serde error if the envelope or one of its nested payload sections cannot be converted to JSON.