pub fn attribute<A: AuditAnalyses>(
analyses: &mut A,
input: AuditAttributionInput<'_>,
) -> AuditOutcomeExpand description
Compare head analyses with a base snapshot, decide the verdict, and set the introduced flags on the dead-code and health findings.