run

Function run 

pub fn run<B: AuditBackend>(
    backend: &B,
    input: AuditRunInput<'_>,
) -> Result<Option<AuditRun<B::Analyses>>, B::Error>
Run one audit. Returns None when the run has no changed files.

Errors

Returns the error of the backend when an analysis or the base checkout fails.