pub fn styling_finding_gates(rules: &RulesConfig, code: &str) -> boolExpand description
Whether a styling finding escalates to error and so gates the verdict.
pub fn styling_finding_gates(rules: &RulesConfig, code: &str) -> boolWhether a styling finding escalates to error and so gates the verdict.