pub fn styling_rule_severity(rules: &RulesConfig, code: &str) -> SeverityExpand description
The severity of the rule that owns a styling finding code. Styling is
verdict-neutral by default (rule warn).
pub fn styling_rule_severity(rules: &RulesConfig, code: &str) -> SeverityThe severity of the rule that owns a styling finding code. Styling is
verdict-neutral by default (rule warn).