pub fn render_review_comment_for_group(
input: &ReviewCommentRenderInput<'_, '_>,
) -> ReviewCommentExpand description
Render one comment from a group of issues sharing the same (path, line).
pub fn render_review_comment_for_group(
input: &ReviewCommentRenderInput<'_, '_>,
) -> ReviewCommentRender one comment from a group of issues sharing the same (path, line).