Module combined_output

Module combined_output 

Combined JSON output assembly shared by CLI and programmatic consumers.

Structs

CombinedCheckJsonSection
Dead-code section inputs for a bare combined JSON report.
CombinedJsonOutputInput
Inputs for bare fallow --format json output assembly.

Functions

serialize_combined_dupes_json
Build a combined duplication section without adding a nested root envelope.
serialize_combined_health_json
Build a combined health section without adding a nested root envelope.
serialize_combined_json
Build and serialize bare combined JSON through the API output boundary.