pub fn build_grouped_compact_lines(
groups: &[ResultGroup],
root: &Path,
) -> Vec<String>Expand description
Build grouped compact output lines, each prefixed with the group key.
Format: group-key\tissue-tag:details
pub fn build_grouped_compact_lines(
groups: &[ResultGroup],
root: &Path,
) -> Vec<String>Build grouped compact output lines, each prefixed with the group key.
Format: group-key\tissue-tag:details