pub struct ManifestPair {
pub manifest: String,
pub base: Option<String>,
pub head: String,
}Expand description
A changed manifest with its base and head text.
Fields
manifest: StringRoot-relative, forward-slashed path of the manifest.
base: Option<String>The base text; None when the manifest did not exist at base.
head: StringThe head text.