pub fn find_duplicates_cached(
root: &Path,
files: &[DiscoveredFile],
config: &DuplicatesConfig,
cache_root: &Path,
) -> DuplicationReportExpand description
Run duplication detection with the persistent token cache enabled.
pub fn find_duplicates_cached(
root: &Path,
files: &[DiscoveredFile],
config: &DuplicatesConfig,
cache_root: &Path,
) -> DuplicationReportRun duplication detection with the persistent token cache enabled.