pub fn has_angular_this_spread(module: &ModuleInfo) -> boolExpand description
Return true when a module spreads this in Angular template context.
pub fn has_angular_this_spread(module: &ModuleInfo) -> boolReturn true when a module spreads this in Angular template context.