pub fn has_dynamic_custom_element_render(module: &ModuleInfo) -> boolExpand description
Return true when a module contains a dynamic custom-element render.
pub fn has_dynamic_custom_element_render(module: &ModuleInfo) -> boolReturn true when a module contains a dynamic custom-element render.