pub enum ChangedFilesError {
InvalidRef(String),
GitMissing(String),
NotARepository,
GitFailed(String),
}Expand description
Classification of a changed-file git failure for editor integrations.
Variants
InvalidRef(String)
Git ref failed validation before invoking git.
GitMissing(String)
git binary not found or not executable.
NotARepository
Command ran but the directory is not a git repository.
GitFailed(String)
Command ran but the ref is invalid or another git error occurred.
Implementations