pub fn type_aware_status(root: &Path) -> TypeAwareStatusExpand description
Inspect the optional semantic companion without loading or analyzing a TypeScript project.
pub fn type_aware_status(root: &Path) -> TypeAwareStatusInspect the optional semantic companion without loading or analyzing a TypeScript project.