pub struct OwnershipSliceFact {
pub module_dirs: Vec<String>,
pub owners: Vec<String>,
pub separable: bool,
}Expand description
The owners of one independent slice of the partition.
Fields
module_dirs: Vec<String>The module directories of the slice, as in
partition.independent_slices.
owners: Vec<String>The distinct owners of the changed files in the slice, sorted. The
(unowned) group is a distinct owner. Never empty.
separable: boolTrue when the slice has exactly one owner, so one owner group can review it on its own.