ProgrammaticHealthAnalysis

Struct ProgrammaticHealthAnalysis 

pub struct ProgrammaticHealthAnalysis {
    pub report: HealthReport,
    pub grouping: Option<HealthGrouping>,
    pub root: PathBuf,
    pub elapsed: Duration,
}
API-owned health analysis payload returned by programmatic runners.

The engine owns execution, but this type is the public runner contract so embedders do not have to construct or depend on engine result structs.

Fields

report: HealthReport

Typed health report produced by the engine.

grouping: Option<HealthGrouping>

Grouped findings when a grouping mode was requested.

root: PathBuf

Resolved analysis root the report paths are relative to.

elapsed: Duration

Analysis wall time.