pub struct TraceExportProgrammaticOutput {
pub output: TraceExportTargetOutput,
}Expand description
Typed programmatic export-trace output before JSON serialization. Carries either an export trace or (fallback) a class / enum / store member trace.
Fields
output: TraceExportTargetOutputTyped export-or-member trace produced by the run.
Implementations
Sourceimpl TraceExportProgrammaticOutput
impl TraceExportProgrammaticOutput
Sourcepub const fn trace(&self) -> &TraceExportTargetOutput
pub const fn trace(&self) -> &TraceExportTargetOutput
Typed export-or-member trace retained by this run.
Sourcepub const fn as_export(&self) -> Option<&TraceExportOutput>
pub const fn as_export(&self) -> Option<&TraceExportOutput>
The export trace, when the target resolved to a top-level export.
Sourcepub const fn as_member(&self) -> Option<&TraceClassMemberOutput>
pub const fn as_member(&self) -> Option<&TraceClassMemberOutput>
The member trace, when the target resolved to a class / enum / store
member (the trace_export fallback, issue #1744).