pub trait ProgrammaticHealthRunner {
// Required method
fn run_programmatic_health(
&self,
options: &ComplexityOptions,
) -> Result<ProgrammaticHealthRun, ProgrammaticError>;
}Expand description
Runner boundary for programmatic health.
This keeps embedders on the typed API contract while still allowing tests and host integrations to provide a custom health runner.
Required Methods
Sourcefn run_programmatic_health(
&self,
options: &ComplexityOptions,
) -> Result<ProgrammaticHealthRun, ProgrammaticError>
fn run_programmatic_health( &self, options: &ComplexityOptions, ) -> Result<ProgrammaticHealthRun, ProgrammaticError>
Run health analysis for public programmatic options.
Errors
Returns a structured programmatic error when the concrete runner cannot resolve options or complete health analysis.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".