TraceExportOutput

Type Alias TraceExportOutput 

pub type TraceExportOutput = ExportTrace;
Concrete export trace output returned by typed programmatic runs.

Aliased Type

pub struct TraceExportOutput {
    pub file: PathBuf,
    pub export_name: String,
    pub file_reachable: bool,
    pub is_entry_point: bool,
    pub is_used: bool,
    pub direct_references: Vec<ExportReference>,
    pub re_export_chains: Vec<ReExportChain>,
    pub reason: String,
}

Fields

file: PathBuf

The file containing the export.

export_name: String

The export name being traced.

file_reachable: bool

Whether the file is reachable from an entry point.

is_entry_point: bool

Whether the file is an entry point.

is_used: bool

Whether the export is considered used.

direct_references: Vec<ExportReference>

Files that reference this export directly.

re_export_chains: Vec<ReExportChain>

Re-export chains that pass through this export.

reason: String

Human-readable reason summary.