pub enum SecurityGateMode {
New,
NewlyReachable,
}Expand description
Gate mode for fallow security --gate <mode>.
Variants
New
Fail when the change introduces a new security-sink candidate on a changed line, not merely a sink in a changed file.
NewlyReachable
Fail when a candidate becomes runtime-reachable from an entry point in head but the matching candidate was not runtime-reachable in base.