pub struct FeatureFlagsRetirementOptions {
pub flag_age: FlagAgeMode,
pub flag_state: Option<PathBuf>,
pub reasons: Vec<RetirementReason>,
pub sort: RetirementSort,
pub min_age_days: Option<u64>,
pub max_flag_age: Option<u64>,
}Expand description
Options of the flag retirement report, the --retirement mode of
fallow flags.
Fields
flag_age: FlagAgeModeHow to measure flag age.
flag_state: Option<PathBuf>Vendor flag export to read, like --flag-state.
reasons: Vec<RetirementReason>Keep only rows with one of these reasons. Empty keeps all rows.
sort: RetirementSortRow order.
min_age_days: Option<u64>Keep only rows at least this many days old.
max_flag_age: Option<u64>Report the flags older than this many days in max_flag_age.