pub struct TypeAwareFileChanges {
pub changed: Vec<PathBuf>,
pub created: Vec<PathBuf>,
pub deleted: Vec<PathBuf>,
pub invalidate_all: bool,
}Expand description
Project-relative changes applied before the next persistent semantic query.
Fields
changed: Vec<PathBuf>Project-relative paths whose contents changed.
created: Vec<PathBuf>Project-relative paths created since the last query.
deleted: Vec<PathBuf>Project-relative paths deleted since the last query.
invalidate_all: boolDiscard the session’s entire semantic state instead of applying the per-file lists.