pub struct TypeAwareSession { /* private fields */ }Expand description
Explicitly owned semantic sidecar session for one canonical project root.
Implementations
Sourceimpl TypeAwareSession
impl TypeAwareSession
Sourcepub fn new(root: &Path) -> Result<Self, TypeAwareError>
pub fn new(root: &Path) -> Result<Self, TypeAwareError>
Start a root-bound persistent semantic session.
Sourcepub fn new_cancellable(
root: &Path,
cancellation: Arc<AtomicBool>,
) -> Result<Self, TypeAwareError>
pub fn new_cancellable( root: &Path, cancellation: Arc<AtomicBool>, ) -> Result<Self, TypeAwareError>
Start a root-bound session that cannot restart after its owner cancels.