pub struct WarmParseStore { /* private fields */ }Expand description
Parsed modules kept across analysis sessions in one process.
Implementations
Sourceimpl WarmParseStore
impl WarmParseStore
Sourcepub fn new(limits: WarmParseLimits) -> WarmParseStore
pub fn new(limits: WarmParseLimits) -> WarmParseStore
Create an empty store with the given memory limits.
Sourcepub fn counts(&self) -> WarmParseCounts
pub fn counts(&self) -> WarmParseCounts
The parse work of the sessions that used this store.