pub trait AuditAnalyses {
// Required methods
fn view(&self) -> AuditAnalysesView<'_>;
fn dead_code_results_mut(&mut self) -> Option<&mut AnalysisResults>;
fn health_report_mut(&mut self) -> Option<&mut HealthReport>;
fn record_type_aware_warning(&mut self, warning: &str);
}Expand description
The analyses a surface ran for one audit side.
Required Methods
Sourcefn view(&self) -> AuditAnalysesView<'_>
fn view(&self) -> AuditAnalysesView<'_>
A read view of the analyses.
Sourcefn dead_code_results_mut(&mut self) -> Option<&mut AnalysisResults>
fn dead_code_results_mut(&mut self) -> Option<&mut AnalysisResults>
The dead-code findings, for the dependency scope and the introduced flags.
Sourcefn health_report_mut(&mut self) -> Option<&mut HealthReport>
fn health_report_mut(&mut self) -> Option<&mut HealthReport>
The health report, for the introduced flags.
Sourcefn record_type_aware_warning(&mut self, warning: &str)
fn record_type_aware_warning(&mut self, warning: &str)
Record the warning of a degraded type-aware comparison on the type-aware metadata of the run.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".