Combined JSON output assembly shared by CLI and programmatic consumers.
Structs
- Combined
Check Json Section - Dead-code section inputs for a bare combined JSON report.
- Combined
Json Output Input - Inputs for bare
fallow --format jsonoutput assembly.
Functions
- serialize_
combined_ dupes_ json - Build a combined duplication section without adding a nested root envelope.
- serialize_
combined_ health_ json - Build a combined health section without adding a nested root envelope.
- serialize_
combined_ json - Build and serialize bare combined JSON through the API output boundary.