pub struct FactoryCallMemberAccessFact {
pub callee_object: String,
pub callee_method: String,
pub member: String,
}Expand description
A member access on a static factory call result.
Fields
callee_object: StringLocal imported class or namespace object used as the factory callee.
callee_method: StringStatic factory method invoked on the callee object.
member: StringMember accessed on the returned instance-like object.