pub struct SemanticFactView<'a> { /* private fields */ }Expand description
Typed-first view over semantic extraction facts.
Extraction populates semantic_facts directly. The member_accesses slice
remains available for consumers that need ordinary source member accesses,
but it is no longer decoded as a string protocol for semantic facts.
Implementations
Sourceimpl<'a> SemanticFactView<'a>
impl<'a> SemanticFactView<'a>
Sourcepub const fn new(
semantic_facts: &'a [SemanticFact],
member_accesses: &'a [MemberAccess],
) -> SemanticFactView<'a>
pub const fn new( semantic_facts: &'a [SemanticFact], member_accesses: &'a [MemberAccess], ) -> SemanticFactView<'a>
Create a typed semantic fact view from current facts plus legacy cache member accesses.
Sourcepub fn facts(self) -> impl Iterator<Item = &'a SemanticFact> + 'a
pub fn facts(self) -> impl Iterator<Item = &'a SemanticFact> + 'a
Iterate typed semantic facts.
Sourcepub fn angular_template_member_names(self) -> impl Iterator<Item = &'a str> + 'a
pub fn angular_template_member_names(self) -> impl Iterator<Item = &'a str> + 'a
Iterate Angular template member references.
Sourcepub fn has_angular_template_members(self) -> bool
pub fn has_angular_template_members(self) -> bool
Return true when any Angular template member reference exists.
Sourcepub fn has_angular_this_spread(self) -> bool
pub fn has_angular_this_spread(self) -> bool
Return true when a module spreads this in Angular template context.
Sourcepub fn ordinary_member_accesses(
self,
) -> impl Iterator<Item = &'a MemberAccess> + 'a
pub fn ordinary_member_accesses( self, ) -> impl Iterator<Item = &'a MemberAccess> + 'a
Iterate ordinary source member accesses.
Sourcepub fn instance_export_bindings(self) -> Vec<InstanceExportBindingFact>
pub fn instance_export_bindings(self) -> Vec<InstanceExportBindingFact>
Collect instance-export binding facts.
Sourcepub fn typed_instance_export_bindings(self) -> Vec<InstanceExportBindingFact>
pub fn typed_instance_export_bindings(self) -> Vec<InstanceExportBindingFact>
Alias for Self::instance_export_bindings.
Sourcepub fn factory_call_member_accesses(self) -> Vec<FactoryCallMemberAccessFact>
pub fn factory_call_member_accesses(self) -> Vec<FactoryCallMemberAccessFact>
Collect static factory call member facts.
Sourcepub fn typed_factory_call_member_accesses(
self,
) -> Vec<FactoryCallMemberAccessFact>
pub fn typed_factory_call_member_accesses( self, ) -> Vec<FactoryCallMemberAccessFact>
Alias for Self::factory_call_member_accesses.
Sourcepub fn factory_fn_member_accesses(self) -> Vec<FactoryFnMemberAccessFact>
pub fn factory_fn_member_accesses(self) -> Vec<FactoryFnMemberAccessFact>
Collect free-function factory-return member facts.
Sourcepub fn typed_factory_fn_member_accesses(self) -> Vec<FactoryFnMemberAccessFact>
pub fn typed_factory_fn_member_accesses(self) -> Vec<FactoryFnMemberAccessFact>
Alias for Self::factory_fn_member_accesses.
Sourcepub fn fluent_chain_member_accesses(self) -> Vec<FluentChainMemberAccessFact>
pub fn fluent_chain_member_accesses(self) -> Vec<FluentChainMemberAccessFact>
Collect static factory fluent-chain member facts.
Sourcepub fn typed_fluent_chain_member_accesses(
self,
) -> Vec<FluentChainMemberAccessFact>
pub fn typed_fluent_chain_member_accesses( self, ) -> Vec<FluentChainMemberAccessFact>
Alias for Self::fluent_chain_member_accesses.
Sourcepub fn fluent_chain_new_member_accesses(
self,
) -> Vec<FluentChainNewMemberAccessFact>
pub fn fluent_chain_new_member_accesses( self, ) -> Vec<FluentChainNewMemberAccessFact>
Collect constructor-rooted fluent-chain member facts.
Sourcepub fn typed_fluent_chain_new_member_accesses(
self,
) -> Vec<FluentChainNewMemberAccessFact>
pub fn typed_fluent_chain_new_member_accesses( self, ) -> Vec<FluentChainNewMemberAccessFact>
Alias for Self::fluent_chain_new_member_accesses.
Sourcepub fn playwright_fixture_uses(self) -> Vec<PlaywrightFixtureUseFact>
pub fn playwright_fixture_uses(self) -> Vec<PlaywrightFixtureUseFact>
Collect Playwright fixture-use facts.
Sourcepub fn typed_playwright_fixture_uses(self) -> Vec<PlaywrightFixtureUseFact>
pub fn typed_playwright_fixture_uses(self) -> Vec<PlaywrightFixtureUseFact>
Alias for Self::playwright_fixture_uses.
Sourcepub fn playwright_fixture_definitions(
self,
) -> Vec<PlaywrightFixtureDefinitionFact>
pub fn playwright_fixture_definitions( self, ) -> Vec<PlaywrightFixtureDefinitionFact>
Collect Playwright fixture-definition facts.
Sourcepub fn typed_playwright_fixture_definitions(
self,
) -> Vec<PlaywrightFixtureDefinitionFact>
pub fn typed_playwright_fixture_definitions( self, ) -> Vec<PlaywrightFixtureDefinitionFact>
Alias for Self::playwright_fixture_definitions.
Sourcepub fn playwright_fixture_aliases(self) -> Vec<PlaywrightFixtureAliasFact>
pub fn playwright_fixture_aliases(self) -> Vec<PlaywrightFixtureAliasFact>
Collect Playwright fixture-alias facts.
Sourcepub fn typed_playwright_fixture_aliases(self) -> Vec<PlaywrightFixtureAliasFact>
pub fn typed_playwright_fixture_aliases(self) -> Vec<PlaywrightFixtureAliasFact>
Alias for Self::playwright_fixture_aliases.
Sourcepub fn playwright_fixture_types(self) -> Vec<PlaywrightFixtureTypeFact>
pub fn playwright_fixture_types(self) -> Vec<PlaywrightFixtureTypeFact>
Collect Playwright fixture-type facts.
Sourcepub fn typed_playwright_fixture_types(self) -> Vec<PlaywrightFixtureTypeFact>
pub fn typed_playwright_fixture_types(self) -> Vec<PlaywrightFixtureTypeFact>
Alias for Self::playwright_fixture_types.