pub struct TestOnlyDependency {
pub package_name: String,
pub path: PathBuf,
pub line: u32,
}Expand description
A production dependency that is only imported by test files. Since it is never used in production code, it could be moved to devDependencies.
Fields
package_name: StringProduction dependency that is only imported by test files, consider moving to devDependencies.
path: PathBufPath to the package.json where the dependency is listed.
line: u321-based line number of the dependency entry in package.json.