Module grouped_output

Module grouped_output 

Shared grouped-output builders for programmatic and CLI consumers.

Structs

ResultGroup
A single grouped dead-code analysis bucket.

Constants

UNOWNED_GROUP_LABEL
Canonical label for issues that cannot be attributed to a group.

Functions

build_duplication_grouping_with
Build grouped duplication output using caller-provided path attribution.
group_analysis_results_with
Partition analysis results into groups using caller-provided path resolvers.
largest_clone_group_owner_with
Return the majority owner for a clone group using caller-provided path attribution.