Shared grouped-output builders for programmatic and CLI consumers.
Structs
- Result
Group - A single grouped dead-code analysis bucket.
Constants
- UNOWNED_
GROUP_ LABEL - Canonical label for issues that cannot be attributed to a group.
Functions
- build_
duplication_ grouping_ with - Build grouped duplication output using caller-provided path attribution.
- group_
analysis_ results_ with - Partition analysis results into groups using caller-provided path resolvers.
- largest_
clone_ group_ owner_ with - Return the majority owner for a clone group using caller-provided path attribution.