Local-only advisory similar-code discovery and provider status. Local-provider orchestration for advisory similar-code discovery.
Structs
- Similar
Code Provider Status - Machine-readable companion and model availability.
Functions
- clear_
project_ cache - Remove only persisted similar-code vectors for one project.
- model_
download_ bytes - Total bytes downloaded by an explicit local model setup.
- provider_
identity - Immutable local provider identity used by public provenance output.
- setup_
local - Download and verify the pinned local model through the installed provider.
- status
- Return the installed local provider status.