pub struct CloneTrace {
pub file: PathBuf,
pub line: usize,
pub matched_instance: Option<CloneInstance>,
pub clone_groups: Vec<TracedCloneGroup>,
}Expand description
Result of tracing a clone: all groups containing the code at a source location or addressed by a stable clone fingerprint.
Fields
file: PathBufFile passed to the trace request, root-relative when a group matches.
line: usize1-based line passed to the trace request or representative group line.
matched_instance: Option<CloneInstance>The matched clone instance, if one exists.
clone_groups: Vec<TracedCloneGroup>Clone groups matched by the trace request.