pub fn estimated_retained_bytes(fingerprints: &[SourceFingerprint]) -> u64Expand description
The estimated heap memory of the parsed modules of the files with these
fingerprints: 12 bytes for each source byte, plus the size of one module
struct for each file. WarmParseLimits::max_retained_bytes applies to
this estimate.